<TS language="mn" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Шинэ хаяг нээх</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Шинэ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Одоогоор сонгогдсон байгаа хаягуудыг сануулах</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Хуулах</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Хаах</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Одоо сонгогдсон байгаа хаягуудыг жагсаалтаас устгах</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Хайлт хийхийн тулд хаяг эсвэл шошгыг оруул</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Сонгогдсон таб дээрхи дата-г экспортлох</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспортдлох</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Устгах</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Зооснуудыг илгээх хаягийг сонгоно уу</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Зооснуудыг хүлээн авах хаягийг сонгоно уу</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>С&amp;онго</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Илгээх хаягууд</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Хүлээн авах хаяг</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Эдгээр Биткойн хаягууд нь илгээх хаягууд. Хүлээн авах хаяг болон тоо хэмжээг илгээхээсээ өмнө сайн нягталж үзэж байна уу</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Хаягийг &amp;Хуулбарлах</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>&amp;Шошгыг хуулбарлах</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Экспорт хийх хаягуудын жагсаалт</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Таслалаар тусгаарлагдсан хүснэгтэн файл (.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Шошго</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Хаяг</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(шошгогүй)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Нууц үгийг оруул</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Шинэ нууц үг</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Шинэ нууц үгийг давтана уу</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Түрүйвчийг цоожлох</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Энэ үйлдэлийг гүйцэтгэхийн тулд та нууц үгээрээ түрүйвчийн цоожийг тайлах хэрэгтэй</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Түрүйвчийн цоожийг тайлах</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Энэ үйлдэлийг гүйцэтгэхийн тулд та эхлээд түрүйвчийн нууц үгийг оруулж цоожийг тайлах шаардлагтай.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Түрүйвчийн цоожийг устгах</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Нууц үгийг солих</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Түрүйвчийн цоожийг баталгаажуулах</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Түрүйвч цоожлогдлоо</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Түрүйвчийн цоожлол амжилттай болсонгүй</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Түрүйвчийн цоожлол дотоод алдаанаас үүдэн амжилттай болсонгүй. Түрүйвч цоожлогдоогүй байна.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Таны оруулсан нууц үг таарсангүй</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Түрүйвчийн цоож тайлагдсангүй</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Таны оруулсан түрүйвчийн цоожийг тайлах нууц үг буруу байна</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Түрүйвчийн цоож амжилттай устгагдсангүй</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Түрүйвчийн нууц үг амжилттай ѳѳр</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Зурвас хавсаргах...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Сүлжээтэй тааруулж байна...</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Гүйлгээнүүд</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Гүйлгээнүүдийн түүхийг харах</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Гарах</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Програмаас Гарах</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Клиентийн тухай</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Клиентийн тухай мэдээллийг харуул</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Сонголтууд...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Түрүйвчийг цоожлох...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Түрүйвчийг Жоорлох...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Нууц Үгийг Солих...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation type="unfinished">Хэтэвч үүсгэх...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Хэтэвч:</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Түрүйвчийг цоожлох нууц үгийг солих</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Илгээх
 </translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Хүлээж авах</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Харуул / Нуу</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Тохиргоо</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Тусламж</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Алдаа</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Анхааруулга</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Мэдээллэл</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Шинэчлэгдсэн</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Оношилгоо ба засварын консолыг онгойлго</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Илгээх хаягууд</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Хүлээн авах хаяг</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation type="unfinished">Хэтэвч хаах...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Алдаа: %1</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Гадагшаа гүйлгээ</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Дотогшоо гүйлгээ</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Түрүйвч &lt;b&gt;цоожтой&lt;/b&gt; ба одоогоор цоож &lt;b&gt;онгорхой&lt;/b&gt; байна</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Түрүйвч &lt;b&gt;цоожтой&lt;/b&gt; ба одоогоор цоож &lt;b&gt;хаалттай&lt;/b&gt; байна</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Хэмжээ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Тѳлбѳр:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Хэмжээ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Огноо</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Баталгаажлаа</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Хэмжээг санах</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Хаягийг санах</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Шошгыг санах</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Хэмжээг санах</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Ѳѳрчлѳлтийг санах</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(шошгогүй)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(ѳѳрчлѳх)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Хэтэвч үүсгэх</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Хэтэвч үүсгэх</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Түрүйвч</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Түрүйвчийг цоожлох</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Шошго</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Хаяг</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Шинэ явуулах хаяг</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Хүлээн авах хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Явуулах хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Түрүйвчийн цоожийг тайлж чадсангүй</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Шинэ түлхүүр амжилттай гарсангүй</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>хувилбар</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Биткойн</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Алдаа</translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    <message>
        <source>N/A</source>
        <translation>Алга Байна</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Unknown...</source>
        <translation type="unfinished">үл мэдэгдэх...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Сүүлийн блокийн хугацаа</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Тѳрѳл</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Хаяг</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Копидсон хаягийг буулгах</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Сонголтууд</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>проксигийн IP хаяг (жишээ нь: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>Сүлжээ</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Түрүйвч</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Ѳѳрчлѳлтүүдийг идэвхижүүлхийн тулд клиентийг ахин эхлүүлэх шаардлагтай</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Алдаа</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Энэ ѳѳрчлѳлтийг оруулахын тулд кли1нт програмыг ахин эхлүүлэх шаардлагтай</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation>Хэрэглэж болох хэмжээ:</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Хаах</translation>
    </message>
    <message>
        <source>or</source>
        <translation>эсвэл</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Type</source>
        <translation>Тѳрѳл</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Хэмжээ</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Алга Байна</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Алдаа: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>үл мэдэгдэх</translation>
    </message>
    <message>
        <source>Blk</source>
        <comment>Tx Watch: Block type abbreviation</comment>
        <translation>Блокийн</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>Гүйлгээний</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG форматын зураг (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Алга Байна</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Клиентийн хувилбар</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Мэдээллэл</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ерѳнхий</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сүлжээ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Нэр</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Холболтын тоо</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Блокийн цуваа</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Түрүйвч: </translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Сүүлийн блокийн хугацаа</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Нээх</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Консол</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Консолыг цэвэрлэх</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Хаягийг санах</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">үл мэдэгдэх</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>Хэмжээ:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Шошго:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>Зурвас:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Харуул</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Сонгогдсон ѳгѳгдлүүдийг устгах</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Устгах</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Хаягийг санах</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Шошгыг санах</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Зурвасыг санах</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Хэмжээг санах</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Түрүйвчийн цоожийг тайлж чадсангүй</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Хаяг:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Хэмжээ:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Шошго:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Зурвас:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Хэтэвч:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Хаягийг &amp;Хуулбарлах</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Огноо</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Шошго</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Зурвас</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(шошгогүй)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(зурвас алга)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Зоос явуулах</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>автоматаар сонгогдсон</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Таны дансны үлдэгдэл хүрэлцэхгүй байна!</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Хэмжээ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Тѳлбѳр:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Сонго...</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Нэгэн зэрэг олон хүлээн авагчруу явуулах</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Хүлээн авагчийг Нэмэх</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бүгдийг Цэвэрлэ</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Баланс:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Явуулах үйлдлийг баталгаажуулна уу</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Яв&amp;уул</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Хэмжээг санах</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Ѳѳрчлѳлтийг санах</translation>
    </message>
    <message>
        <source>or</source>
        <translation>эсвэл</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Зоос явуулахыг баталгаажуулна уу</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Явуул</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Тѳлѳх хэмжээ 0.-оос их байх ёстой</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Энэ хэмжээ таны балансаас хэтэрсэн байна.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Гүйлгээний тѳлбѳр %1-ийг тооцхоор нийт дүн нь таны балансаас хэтрээд байна.</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Анхаар:Буруу Биткойны хаяг байна</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(шошгогүй)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Дүн:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Тѳлѳх &amp;хаяг:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Шошго:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Копидсон хаягийг буулгах</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Зурвас:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Тѳлѳх хаяг:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Энэ цонхыг хаагдтал компьютерээ бүү унтраагаарай</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Копидсон хаягийг буулгах</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Бүгдийг Цэвэрлэ</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation type="unfinished">&amp;Баталгаажуулах мэссэж</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>%1 хүртэл нээлттэй</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/баталгаажаагүй</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 баталгаажилтууд</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Огноо</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>үл мэдэгдэх</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Зурвас</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Тодорхойлолт</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Гүйлгээний</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Хэмжээ</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Гүйлгээний дэлгэрэнгүйг энэ бичил цонх харуулж байна</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Огноо</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тѳрѳл</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Шошго</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>%1 хүртэл нээлттэй</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Баталгаажаагүй</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Баталгаажлаа (%1 баталгаажилт)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Зѳрчилдлѳѳ</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Үүсгэгдсэн гэхдээ хүлээн авагдаагүй</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Хүлээн авсан хаяг</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Хүлээн авагдсан хаяг</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Явуулсан хаяг</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Ѳѳрлүүгээ хийсэн тѳлбѳр</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Олборлогдсон</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(алга байна)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(шошгогүй)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Гүйлгээний байдал. Энд хулганыг авчирч баталгаажуулалтын тоог харна уу.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Гүйлгээг хүлээн авсан огноо ба цаг.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Гүйлгээний тѳрѳл</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Балансаас авагдсан болон нэмэгдсэн хэмжээ.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Бүгд</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ѳнѳѳдѳр</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Энэ долоо хоног</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Энэ сар</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Ѳнгѳрсѳн сар</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Энэ жил</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Хүлээн авсан хаяг</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Явуулсан хаяг</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Олборлогдсон</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Бусад</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Хамгийн бага хэмжээ</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Хаягийг санах</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Шошгыг санах</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Хэмжээг санах</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Шошгыг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>&amp;Show transaction details</source>
        <translation type="unfinished">&amp;Гүйлгээний дэлгэрэнгүйг харуул</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Таслалаар тусгаарлагдсан хүснэгтэн файл (.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Баталгаажлаа</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Огноо</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тѳрѳл</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Шошго</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Хаяг</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>Тодорхойлолт</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation>Гүйлгээнүй түүхийг %1-д амжилттай хадгаллаа.</translation>
    </message>
    <message>
        <source>to</source>
        <translation>-рүү/руу</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Алдаа</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Зоос явуулах</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспортдлох</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Сонгогдсон таб дээрхи дата-г экспортлох</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Түрүйвчийг Жоорлох</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Алдаа</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Хаягуудыг ачааллаж байна...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Таны дансны үлдэгдэл хүрэлцэхгүй байна</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Блокийн индексүүдийг ачааллаж байна...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Түрүйвчийг ачааллаж байна...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ахин уншиж байна...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ачааллаж дууслаа</translation>
    </message>
</context>
</TS>